PCB Environment: dsn::Pin Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
dsn::Pin Struct Reference

## Public Member Functions
std::string | str () const

## Data Fields
Padstack * | padstack {0}
std::string | name
std::string | net
int | index
int | angle {0}
double | x
double | y
int | z0 = std::numeric_limits<int>::max()
int | z1 = -1
double | clearance {0.0}
bool | has_net {false}
std::optional< std::string > | compound

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp